from django.contrib import admin
from unfold.admin import ModelAdmin, TabularInline
from .models import ImageFile, Category, Portfolio, Order

# Inline for Portfolio images
class PortfolioImageInline(TabularInline):
    model = Portfolio.images.through  # Many-to-many relationship
    extra = 1
    verbose_name = "Изображение портфолио"
    verbose_name_plural = "Изображения портфолио"
    fields = ('imagefile',)  # Keep the field for selecting ImageFile
    # Removed readonly_fields to allow editing
    raw_id_fields = ('imagefile',)  # Use raw_id_fields for better performance with large ImageFile sets

# ImageFile Admin
@admin.register(ImageFile)
class ImageFileAdmin(ModelAdmin):
    list_display = ('id', 'image_tag', 'created_at')
    readonly_fields = ('image_tag',)
    search_fields = ('id',)
    list_filter = ('created_at',)

# Category Admin
@admin.register(Category)
class CategoryAdmin(ModelAdmin):
    list_display = ('id', 'name', 'slug', 'created_at')
    prepopulated_fields = {'slug': ('name',)}
    search_fields = ('name', 'slug')
    list_filter = ('created_at',)
    fields = ('name', 'slug', 'created_at', 'updated_at')
    readonly_fields = ('created_at', 'updated_at')

# Portfolio Admin
@admin.register(Portfolio)
class PortfolioAdmin(ModelAdmin):
    list_display = ('id', 'name', 'company', 'category', 'primary_image_tag', 'created_at')
    search_fields = ('name', 'company')
    list_filter = ('category', 'created_at')
    inlines = [PortfolioImageInline]
    readonly_fields = ('primary_image_tag', 'created_at', 'updated_at')
    fields = (
        'name', 'category', 'company', 'description',
        'start_date', 'end_date', 'cost',
        'created_at', 'updated_at', 'primary_image_tag'
    )

# Order Admin
@admin.register(Order)
class OrderAdmin(ModelAdmin):
    list_display = ('id', 'name', 'email', 'ad_type', 'budget', 'created_at')
    search_fields = ('name', 'email')
    list_filter = ('ad_type', 'created_at')
    fields = (
        'ad_type', 'project_description', 'budget',
        'name', 'email', 'phone',
        'created_at', 'updated_at'
    )
    readonly_fields = ('created_at', 'updated_at')