from django.shortcuts import render, redirect
from django.contrib import messages
from django.views.generic import TemplateView
from .models import Portfolio, Category, Order

def index_view(request):
    portfolios = Portfolio.objects.all()
    categories = Category.objects.all()
    orders = Order.objects.all().order_by('-created_at')[:5]
    return render(request, 'index.html', {
        'portfolios': portfolios,
        'categories': categories,
        'order_ad_type_choices': Order.get_ad_type_choices(),
        'orders': orders,
    })

def submit_order(request):
    if request.method == 'POST':
        try:
            # Create an Order instance from form data
            Order.objects.create(
                ad_type=request.POST['ad-type'],
                project_description=request.POST['project-desc'],
                budget=request.POST['budget'],
                name=request.POST['name'],
                email=request.POST['email'],
                phone=request.POST['phone']
            )
            # Add success message
            messages.success(request, 'Ваш заказ успешно отправлен!')
            return redirect('index_view')
        except Exception as e:
            # Add error message in case of failure
            messages.error(request, f'Ошибка при отправке заказа: {str(e)}')
            return redirect('index_view')
    # If not POST, redirect to homepage
    return redirect('index_view')



class PrivacyPolicyView(TemplateView):
    template_name = 'legal/privacy_policy.html'

class TermsOfUseView(TemplateView):
    template_name = 'legal/terms_of_use.html'

